@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 use vars qw($VERSION @ISA);
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 #--------------------------------------------------------------------------
 
@@ -25,6 +25,7 @@ Searches for book information from the Pearson Education's online catalog.
 ### CHANGES ###############################################################
 #   0.01	07/04/2004	Initial Release
 #	0.02	19/04/2004	Test::More added as a prerequisites for PPMs
+#	0.03	11/05/2004	Added publisher as a book attribute
 ###########################################################################
 
 #--------------------------------------------------------------------------
@@ -76,6 +77,7 @@ a valid page is returned, the following fields are returned via the book hash:
   image_link
   description
   pubdate
+  publisher
 
 The book_link and image_link refer back to the Pearson Education UK website. 
 
@@ -141,6 +143,7 @@ END
 		'thumb_link'	=> $data->{thumb},
 		'description'	=> $data->{description},
 		'pubdate'		=> $data->{pubdate},
+		'publisher'		=> 'Pearson Education',
 	};
 	$self->book($bk);
 	$self->found(1);
